@@ -36,14 +36,14 @@ from client_class import HTTPSClientCertTransport
 from methods_func import call_method, get_method_argparser, parse, get_view
 from calculate.lib.utils.files import makeDirectory, readLinesFile
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('calculate_console',sys.modules[__name__])
+setLocalTranslate('cl_console3',sys.modules[__name__])
 
 def client_signal(client):
     Vars = DataVarsCore()
     Vars.importCore()
     Vars.flIniFile()
     try:
-        client_active = Vars.Get('cl_core_client_active_period')
+        client_active = Vars.Get('core.cl_core_client_active_period')
     except:
         client_active = 15
     while True:
@@ -246,6 +246,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
         from pid_information import client_pid_kill
         return client_pid_kill(client, args.pid_kill)
 
+    retCode = 0
     if not args.method:
         wait_thread.stop()
         client_list_methods(client)
@@ -253,7 +254,8 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
 
     elif args.method and args.help:
         view_params = get_view_params(client, args.method + '_view',
-                                      step = None, expert = True)
+                                      step = None, expert = True,
+                                      onlyhelp = True)
         view = get_view(client, args.method, client.sid, view_params)
         wait_thread.stop()
         sys.stdout.write("\b")
@@ -264,10 +266,10 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
 
     else:
         try:
-            client.frame_period = clVarsCore.Get('cl_core_get_frame_period')
+            client.frame_period = clVarsCore.Get('core.cl_core_get_frame_period')
         except:
             client.frame_period = 2
-        method_result = call_method(client, args, wait_thread)
+        method_result = call_method(client, args, unknown_args, wait_thread)
         if method_result:
             client.no_progress = args.no_progress
             try:
@@ -287,7 +289,7 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
                     elif result == -2:
                         print _("Session not matching your certificate")
                     elif result == 1:
-                        print _("Failed to kill the process")
+                        print _("Failed to terminate the process")
 #                    get_entire_frame(client, pid)
                     analysis(client, client.sid, method_result)
                 except Exception, e:
@@ -298,11 +300,12 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
                 pid = int(mess.message)
             except:
                 return 1
-
+            retCode = \
+                1 if int(client.service.pid_info(client.sid,pid)[0][1]) else 0
             client.service.clear_pid_cache(client.sid, pid)
         client.service.clear_method_cache(client.sid, args.method)
     wait_thread.stop()
-    return 0
+    return retCode
 
 def main(wait_thread):
     parser = parse()
@@ -343,7 +346,7 @@ def main(wait_thread):
     host = args.host
     path_to_cert = args.path_to_cert
     if not path_to_cert:
-        path_to_cert = clVarsCore.Get('cl_client_cert_dir')
+        path_to_cert = clVarsCore.Get('core.cl_client_cert_dir')
     path_to_cert = path_to_cert.replace("~",homePath)
 
     for dirs in ['', 'ca', 'trusted']:
@@ -414,7 +417,7 @@ def main(wait_thread):
             except KeyboardInterrupt:
                 wait_thread.stop()
                 red = '\n'+'\033[31m * \033[0m'
-                print red + _('Interrupted by the user')
+                print red + _("Manually interrupted")
             except Exception, e:
                 wait_thread.stop()
                 if type(e.message) != int:
@@ -434,7 +437,7 @@ def main(wait_thread):
         except KeyboardInterrupt:
             wait_thread.stop()
             red = '\n'+'\033[31m * \033[0m'
-            print red + _('Interrupted by the user')
+            print red + _("Manually interrupted")
         except Exception, e:
             print _("Exception: %s") %e
             tb.print_exc()
@@ -455,7 +458,7 @@ def main(wait_thread):
     except KeyboardInterrupt:
         wait_thread.stop()
         red = '\n'+'\033[31m * \033[0m'
-        print red + _('Interrupted by the user')
+        print red + _("Manually interrupted")
 
     try:
         import glob
@@ -516,7 +519,7 @@ def main(wait_thread):
         except KeyboardInterrupt:
             wait_thread.stop()
             red = '\n'+'\033[31m * \033[0m'
-            print red + _('Interrupted by the user')
+            print red + _("Manually interrupted")
         except Exception, e:
             wait_thread.stop()
             if type(e.message) != int:
@@ -537,7 +540,7 @@ def main(wait_thread):
     except KeyboardInterrupt:
         wait_thread.stop()
         red = '\n'+'\033[31m * \033[0m'
-        print red + _('Interrupted by the user')
+        print red + _("Manually interrupted")
     except Exception, e:
         print _("Exception: %s") %e
         tb.print_exc()
