@@ -31,7 +31,7 @@ from cookielib import CookieJar, DefaultCookiePolicy
 from logging import getLogger
 from calculate.console.datavars import DataVarsConsole
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('calculate_console',sys.modules[__name__])
+setLocalTranslate('cl_console3',sys.modules[__name__])
 #import cert_func.verify
 log = getLogger(__name__)
 flag = 0
@@ -114,16 +114,16 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
         clVarsCore.flIniFile()
         
         list_ca_certs.reverse()
-        system_ca_db = clVarsCore.Get('cl_glob_root_cert')
+        system_ca_db = clVarsCore.Get('core.cl_glob_root_cert')
 
         clVars = DataVars()
         clVars.flIniFile()
         homePath = clVars.Get('ur_home_path')
-        cl_client_cert_dir = clVarsCore.Get('cl_client_cert_dir')
+        cl_client_cert_dir = clVarsCore.Get('core.cl_client_cert_dir')
         cl_client_cert_dir = cl_client_cert_dir.replace("~",homePath)
         root_cert_md5 = os.path.join(cl_client_cert_dir, "ca/cert_list")
 
-        user_root_cert = clVarsCore.Get('cl_user_root_cert')
+        user_root_cert = clVarsCore.Get('core.cl_user_root_cert')
         user_root_cert = user_root_cert.replace("~",homePath)
 
         for cert in list_ca_certs:
@@ -180,7 +180,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                 print _("filename = "), filename
                 print _("Certificate added")
             else:
-                print _("A file with CA certificates now exists")
+                print _("The file containing the CA certificate now exists")
         get_CRL(cl_client_cert_dir)
 
     def add_ca_cert(self, cert, list_ca_certs):
@@ -190,11 +190,11 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
         client.wsdl.services[0].setlocation(url)
         cert = client.service.get_ca()
         if cert == '1':
-            print _('Invalid server certificate')
+            print _("Invalid server certificate!")
             raise Exception(1)
 
         if cert == '2':
-            print _('CA not found on the server')
+            print _("CA certificate not found on the server")
             raise Exception(1)
             
         try:
@@ -238,7 +238,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
             print "%s : %s" %(item[0], item[1])
         
         print '\n' + _('Add this server certificate to trusted (s) or')
-        print _('Try to add the CA and ROOT certificates to trusted (c) or')
+        print _('Try to add the CA and root certificates to trusted (c) or')
         choice = raw_input (_("Quit (q)? s/c/[q]: "))
         if choice.lower() in ['s', 'c']:
             #self.sock = ssl.wrap_socket(sock)
@@ -275,7 +275,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
             clVars = DataVarsCore()
             clVars.importCore()
             clVars.flIniFile()
-            cl_client_cert_dir = clVars.Get('cl_client_cert_dir')
+            cl_client_cert_dir = clVars.Get('core.cl_client_cert_dir')
             homePath = clVars.Get('ur_home_path')
             cl_client_cert_dir = cl_client_cert_dir.replace("~",homePath)
             root_cert_dir = os.path.join(cl_client_cert_dir, "ca")
@@ -287,7 +287,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                     print _("Failed to create directory %s") %root_cert_dir
                     raise Exception(1)
             
-            print '\n' + _("Try to add the CA and ROOT certificates")
+            print '\n' + _("Add the CA and root certificates")
             self.list_ca_certs = []
             self.add_ca_cert(cert, self.list_ca_certs)
             return 3
@@ -379,7 +379,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
         self.Vars = DataVarsConsole()
         self.Vars.importConsole()
         self.Vars.flIniFile()
-        user_root_cert = self.Vars.Get('cl_user_root_cert')
+        user_root_cert = self.Vars.Get('core.cl_user_root_cert')
         homePath = self.Vars.Get('ur_home_path')
         user_root_cert = user_root_cert.replace("~",homePath)
         result_user_root = 1
@@ -389,7 +389,7 @@ class CheckingClientHTTPSConnection(CheckingHTTPSConnection):
                 result_user_root = self.connect_trusted_root(sock, \
                                             user_root_cert, self.CRL_PATH)
             if result_user_root == 1:
-                glob_root_cert = self.Vars.Get('cl_glob_root_cert')
+                glob_root_cert = self.Vars.Get('core.cl_glob_root_cert')
                 result_root_con = 1
                 if os.path.exists(glob_root_cert):
                     sock = socket.create_connection((self.host, self.port),
@@ -503,4 +503,4 @@ class HTTPSClientCertTransport(HttpTransport):
             self.urlopener.add_handler(proxy_handler)
         if proxy_auth_handler:
             self.urlopener.add_handler(proxy_auth_handler)
-        self.urlopener.addheaders = [('User-agent', self.user_agent_string)]
\ No newline at end of file
+        self.urlopener.addheaders = [('User-agent', self.user_agent_string)]
