@@ -17,12 +17,12 @@
 import argparse, sys
 from function import _create_obj, get_view_params, print_brief
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('calculate_console',sys.modules[__name__])
+setLocalTranslate('cl_console3',sys.modules[__name__])
 import urllib2
 
 from calculate.core.server.methods_func import get_method_argparser, \
                               collect_object, RawAndDefaultsHelpFormatter, \
-                              check_result_msg, get_param_pwd
+                              check_result_msg, get_param_pwd, getErrorOnParam
 
 def parse():
     parser = argparse.ArgumentParser(add_help=False,
@@ -35,7 +35,7 @@ def parse():
         '--method', type=str, dest='method', help=_('call method'))
     parser.add_argument(
         '-l', '--lang', type=str, dest='lang',
-        help=_('language for translation'))
+        help=_('translation language'))
     parser.add_argument(
         '-p', '--port', type=int, default = '8888', dest='port',
         help=_('port number'))
@@ -45,7 +45,7 @@ def parse():
     parser.add_argument(
         '--gen-cert-by', type=str, dest='by_host', metavar = 'HOST',
         help = \
-           _('post a request on the server for the certificate to be signed'))
+           _('send a certificate signature request to the server'))
     parser.add_argument(
         '--get-cert-from', type=str, dest='from_host', metavar = 'HOST',
         help=_('get the signed certificate from the server'))
@@ -57,7 +57,7 @@ def parse():
         dest='list_pid', help=_("view the list of running processes"))
     parser.add_argument(
         '-d', '--dump',  action='store_true', default=False, dest = 'dump',
-        help=_('dump (to be used with --list-pid)'))
+        help=_('dump (to be used with option --list-pid)'))
     parser.add_argument(
         '--pid-result',  type=int, metavar = 'PID',
         dest='pid_res', help=_("view the result of the process"))
@@ -77,7 +77,7 @@ def parse():
     parser.add_argument(
         '--session-list', action='store_true', default=False,
         dest='session_list',
-        help=_("view the active sessions list on the server"))
+        help=_("view the active server sessions"))
     parser.add_argument(
         '--update-crl', action='store_true', default=False,
         dest='update_crl', help=_("update the revocation list"))
@@ -93,7 +93,7 @@ def parse():
     parser.add_argument(
         '-P', action='store_true', default=False,
         dest = 'stdin_passwd',
-        help=_('use passwords for the users accounts from standard input'))
+        help=_("use passwords from standard input for users accounts"))
     return parser
 
 def get_view(client, method, sid, view_params):
@@ -104,7 +104,7 @@ def get_view(client, method, sid, view_params):
         raise Exception(1)
     return view
 
-def call_method(client, args, wait_thread):
+def call_method(client, args, unknown_args, wait_thread):
     method = args.method
     no_questions = args.no_questions
     stdin_passwd = args.stdin_passwd
@@ -115,7 +115,7 @@ def call_method(client, args, wait_thread):
     method_parser = get_method_argparser(view, args)
     param_object = _create_obj(client, method)
     try:
-        args, unknown_args = method_parser.parse_known_args()
+        args, unknown_args = method_parser.parse_known_args(unknown_args)
     except SystemExit:
         raise Exception(1)
     for i in unknown_args:
@@ -165,7 +165,7 @@ def call_method(client, args, wait_thread):
                     ask = 'no'
                     red = '\n'+'\033[31m * \033[0m'
                 if ask.lower() in ['n', 'no']:
-                    print red + _('Interrupted by the user')
+                    print red + _("Manually interrupted")
                     return None
                 if ask.lower() in ['y', 'yes']:
                     break
@@ -182,10 +182,7 @@ def call_method(client, args, wait_thread):
             for Group in view.groups.GroupField:
                 for field in Group.fields.Field:
                     if field.name == error.field:
-                        if field.opt.shortopt or field.opt.longopt:
-                            params_text += _('Wrong option ')
-                            params_text += ', '.join(filter(None,
-                                [field.opt.shortopt, field.opt.longopt]))+'. '
+                        params_text += getErrorOnParam(args,field)
             red = '\033[31m * \033[0m'
             _print ('\r' + red + params_text + error.message)
         return None
